/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ../../../dist/idl/mozIGeckoMediaPluginService.idl
 */

#ifndef __gen_mozIGeckoMediaPluginService_h__
#define __gen_mozIGeckoMediaPluginService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIThread_h__
#include "nsIThread.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class GMPVideoDecoder;
class GMPVideoEncoder;
class GMPVideoHost;

/* starting interface:    mozIGeckoMediaPluginService */
#define MOZIGECKOMEDIAPLUGINSERVICE_IID_STR "bf5a9086-70f5-4d38-832d-1609bbf963cd"

#define MOZIGECKOMEDIAPLUGINSERVICE_IID \
  {0xbf5a9086, 0x70f5, 0x4d38, \
    { 0x83, 0x2d, 0x16, 0x09, 0xbb, 0xf9, 0x63, 0xcd }}

class NS_NO_VTABLE mozIGeckoMediaPluginService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(MOZIGECKOMEDIAPLUGINSERVICE_IID)

  /* readonly attribute nsIThread thread; */
  NS_IMETHOD GetThread(nsIThread * *aThread) = 0;

  /* GMPVideoDecoder getGMPVideoDecoderVP8 (out GMPVideoHost outVideoHost); */
  NS_IMETHOD GetGMPVideoDecoderVP8(GMPVideoHost **outVideoHost, GMPVideoDecoder **_retval) = 0;

  /* GMPVideoEncoder getGMPVideoEncoderVP8 (out GMPVideoHost outVideoHost); */
  NS_IMETHOD GetGMPVideoEncoderVP8(GMPVideoHost **outVideoHost, GMPVideoEncoder **_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(mozIGeckoMediaPluginService, MOZIGECKOMEDIAPLUGINSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_MOZIGECKOMEDIAPLUGINSERVICE \
  NS_IMETHOD GetThread(nsIThread * *aThread); \
  NS_IMETHOD GetGMPVideoDecoderVP8(GMPVideoHost **outVideoHost, GMPVideoDecoder **_retval); \
  NS_IMETHOD GetGMPVideoEncoderVP8(GMPVideoHost **outVideoHost, GMPVideoEncoder **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_MOZIGECKOMEDIAPLUGINSERVICE(_to) \
  NS_IMETHOD GetThread(nsIThread * *aThread) { return _to GetThread(aThread); } \
  NS_IMETHOD GetGMPVideoDecoderVP8(GMPVideoHost **outVideoHost, GMPVideoDecoder **_retval) { return _to GetGMPVideoDecoderVP8(outVideoHost, _retval); } \
  NS_IMETHOD GetGMPVideoEncoderVP8(GMPVideoHost **outVideoHost, GMPVideoEncoder **_retval) { return _to GetGMPVideoEncoderVP8(outVideoHost, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_MOZIGECKOMEDIAPLUGINSERVICE(_to) \
  NS_IMETHOD GetThread(nsIThread * *aThread) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetThread(aThread); } \
  NS_IMETHOD GetGMPVideoDecoderVP8(GMPVideoHost **outVideoHost, GMPVideoDecoder **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGMPVideoDecoderVP8(outVideoHost, _retval); } \
  NS_IMETHOD GetGMPVideoEncoderVP8(GMPVideoHost **outVideoHost, GMPVideoEncoder **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGMPVideoEncoderVP8(outVideoHost, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public mozIGeckoMediaPluginService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_MOZIGECKOMEDIAPLUGINSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS(_MYCLASS_, mozIGeckoMediaPluginService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute nsIThread thread; */
NS_IMETHODIMP _MYCLASS_::GetThread(nsIThread * *aThread)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* GMPVideoDecoder getGMPVideoDecoderVP8 (out GMPVideoHost outVideoHost); */
NS_IMETHODIMP _MYCLASS_::GetGMPVideoDecoderVP8(GMPVideoHost **outVideoHost, GMPVideoDecoder **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* GMPVideoEncoder getGMPVideoEncoderVP8 (out GMPVideoHost outVideoHost); */
NS_IMETHODIMP _MYCLASS_::GetGMPVideoEncoderVP8(GMPVideoHost **outVideoHost, GMPVideoEncoder **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_mozIGeckoMediaPluginService_h__ */
